@@ -67,6 +67,16 @@ void CL_InitEnts(void) {
 	cl_modelnames[mi_flag] = "progs/flag.mdl";
 	cl_modelnames[mi_tf_flag] = "progs/tf_flag.mdl";
 	cl_modelnames[mi_tf_stan] = "progs/tf_stan.mdl";
+	cl_modelnames[mi_stag] = "progs/stag.mdl";
+	cl_modelnames[mi_basrkey] = "progs/basrkey.bsp";
+	cl_modelnames[mi_basbkey] = "progs/basbkey.bsp";
+	cl_modelnames[mi_w_s_key] = "progs/w_s_key.mdl";
+	cl_modelnames[mi_w_g_key] = "progs/w_g_key.mdl";
+	cl_modelnames[mi_b_g_key] = "progs/b_g_key.mdl";
+	cl_modelnames[mi_b_s_key] = "progs/b_s_key.mdl";
+	cl_modelnames[mi_ff_flag] = "progs/ff_flag.mdl";
+	cl_modelnames[mi_harbflag] = "progs/harbflag.mdl";
+	cl_modelnames[mi_princess] = "progs/princess.mdl";
 	cl_modelnames[mi_explod1] = "progs/s_explod.spr";
 	cl_modelnames[mi_explod2] = "progs/s_expl.spr";
 	cl_modelnames[mi_h_player] = "progs/h_player.mdl";
@@ -155,9 +165,11 @@ static qbool is_monster (int modelindex)
 	return false;
 }
 
-void CL_ClearScene(void)
-{
-	memset(cl_visents.list, 0, sizeof(cl_visents.list));
+void CL_ClearScene(void) {
+	if (cl_visents.count > 0)
+	{
+		memset(cl_visents.list, 0, sizeof(cl_visents.list[0]) * cl_visents.count);
+	}
 	memset(cl_visents.typecount, 0, sizeof(cl_visents.typecount));
 	cl_visents.count = 0;
 }
@@ -171,7 +183,18 @@ void CL_AddEntityToList(visentlist_t* list, visentlist_entrytype_t vistype, enti
 
 		ent = &list->list[cl_visents.count].ent;
 		list->list[cl_visents.count].type = type;
-		list->list[cl_visents.count].distance = VectorDistanceQuick(cl.simorg, ent->origin);
+		if (vistype == visent_alpha) {
+			// Sort transparent entities based on closest point for stable back-to-front rendering.
+			vec3_t distance;
+			int i;
+			for (i = 0; i < 3; i++) {
+				distance[i] = r_refdef.vieworg[i] - ent->origin[i];
+				distance[i] -= bound(ent->model->mins[i], distance[i], ent->model->maxs[i]);
+			}
+			list->list[cl_visents.count].distance = DotProduct(distance, distance);
+		} else {
+			list->list[cl_visents.count].distance = VectorDistanceQuick(cl.simorg, ent->origin);
+		}
 		list->list[cl_visents.count].draw[vistype] = true;
 
 		ent->outlineScale = 0.5f * (r_refdef2.outlineBase + DotProduct(ent->origin, r_refdef2.outline_vpn));
@@ -223,6 +246,9 @@ void CL_AddEntity(entity_t *ent)
 		vistype = visent_firstpass;
 		ent->renderfx |= RF_NOSHADOW;
 	}
+	else if (ent->alpha > 0.0f && ent->alpha < 1.0f) {
+		vistype = visent_alpha;
+	}
 	else {
 		vistype = visent_normal;
 	}
@@ -486,8 +512,16 @@ void CL_ParseDelta (entity_state_t *from, entity_state_t *to, int bits) {
 #endif
 
 	to->flags = bits;
-	if (bits & U_MODEL)
+	if (bits & U_MODEL) {
 		to->modelindex = MSG_ReadByte();
+#ifdef FTE_PEXT_MODELDBL
+		if (morebits & U_FTE_MODELDBL) {
+			to->modelindex += 256;
+		}
+	} else if (morebits & U_FTE_MODELDBL) {
+		to->modelindex = MSG_ReadShort();
+#endif
+	}
 
 	if (bits & U_FRAME)
 		to->frame = MSG_ReadByte ();
@@ -548,6 +582,15 @@ void CL_ParseDelta (entity_state_t *from, entity_state_t *to, int bits) {
 	}
 #endif
 
+#ifdef FTE_PEXT_COLOURMOD
+	if ((morebits & U_FTE_COLOURMOD) && (cls.fteprotocolextensions & FTE_PEXT_COLOURMOD))
+	{
+		to->colourmod[0] = MSG_ReadByte();
+		to->colourmod[1] = MSG_ReadByte();
+		to->colourmod[2] = MSG_ReadByte();
+	}
+#endif
+
 #ifdef FTE_PEXT_ENTITYDBL
 	if (morebits & U_FTE_ENTITYDBL) {
 		to->number += 512;
@@ -558,11 +601,6 @@ void CL_ParseDelta (entity_state_t *from, entity_state_t *to, int bits) {
 		to->number += 1024;
 	}
 #endif
-#ifdef FTE_PEXT_MODELDBL
-	if (morebits & U_FTE_MODELDBL) {
-		to->modelindex += 256;
-	}
-#endif
 #endif
 }
 
@@ -901,7 +939,18 @@ void CL_LinkPacketEntities(void)
 			{
 				qbool flagcolor = false;
 
-				if (cl.teamfortress && (state->modelindex == cl_modelindices[mi_tf_flag] || state->modelindex == cl_modelindices[mi_tf_stan]))
+				if (cl.teamfortress && (state->modelindex == cl_modelindices[mi_tf_flag] || 
+										state->modelindex == cl_modelindices[mi_tf_stan] || 
+										state->modelindex == cl_modelindices[mi_stag] || 
+										state->modelindex == cl_modelindices[mi_basrkey] || 
+										state->modelindex == cl_modelindices[mi_basbkey] || 
+										state->modelindex == cl_modelindices[mi_w_s_key] ||
+										state->modelindex == cl_modelindices[mi_w_g_key] ||
+										state->modelindex == cl_modelindices[mi_b_g_key] ||
+										state->modelindex == cl_modelindices[mi_b_s_key] ||
+										state->modelindex == cl_modelindices[mi_ff_flag] ||
+										state->modelindex == cl_modelindices[mi_harbflag] ||
+										state->modelindex == cl_modelindices[mi_princess]))
 					flagcolor = true;
 				else if (state->modelindex == cl_modelindices[mi_flag])
 					flagcolor = true;
@@ -1024,8 +1073,23 @@ void CL_LinkPacketEntities(void)
 			}
 		}
 #if defined(FTE_PEXT_TRANS)
-		//set trans
-		ent.alpha = state->trans/255.0;
+		// set trans, 0 and 255 are both opaque, represented by alpha 0.
+		ent.alpha = state->trans == 255 ? 0.0f : (float)state->trans / 254.0f;
+#endif
+#if defined(FTE_PEXT_COLOURMOD)
+		// colourmod 0 is unset, 32 (1.0) incurs no color change
+		if ((state->colourmod[0] > 0 || state->colourmod[1] > 0 || state->colourmod[2] > 0) &&
+			!(state->colourmod[0] == 32 && state->colourmod[1] == 32 && state->colourmod[2] == 32))
+		{
+			ent.r_modelcolor[0] = ((float) state->colourmod[0] * 8.0f) / 256.0f;
+			ent.r_modelcolor[1] = ((float) state->colourmod[1] * 8.0f) / 256.0f;
+			ent.r_modelcolor[2] = ((float) state->colourmod[2] * 8.0f) / 256.0f;
+			ent.renderfx |= RF_FORCECOLOURMOD;
+		}
+		else
+		{
+			ent.renderfx &= ~RF_FORCECOLOURMOD;
+		}
 #endif
 
 		if (ent.model->flags & EF_ROTATE)
@@ -1367,7 +1431,23 @@ void CL_ParsePlayerinfo (void)
 	} 
 	else 
 	{
-		flags = state->flags = MSG_ReadShort ();
+#ifdef FTE_PEXT_TRANS
+		flags = (unsigned short) MSG_ReadShort ();
+		if (cls.fteprotocolextensions & FTE_PEXT_TRANS)
+		{
+			if (flags & PF_EXTRA_PFS)
+				flags |= MSG_ReadByte() << 16;
+		}
+		else
+		{
+			// Without PEXT_TRANS there's no PF_EXTRA_PFS, move
+			// PF_ONGROUND and PF_SOLID to their expected offsets.
+			flags = (flags & 0x3fff) | (flags & 0xc000) << 8;
+		}
+		state->flags = flags;
+#else
+		state->flags = flags = MSG_ReadShort ();
+#endif
 
 		state->messagenum = cl.parsecount;
 		if (cls.mvdprotocolextensions1 & MVD_PEXT1_FLOATCOORDS) {
@@ -1446,7 +1526,6 @@ void CL_ParsePlayerinfo (void)
 			state->weaponframe = 0;
 
 
-		state->alpha = 255;
 #ifdef FTE_PEXT_TRANS
 		if (flags & PF_TRANS_Z && cls.fteprotocolextensions & FTE_PEXT_TRANS)
 			state->alpha = MSG_ReadByte();
@@ -1516,7 +1595,29 @@ guess_pm_type:
 			// Write out here - generally packets are copied, but flags for userdelta were changed
 			//   in protocol 27 - we always write out in new format
 			MSG_WriteByte(&cls.demomessage, num);
+#if defined(FTE_PEXT_TRANS)
+			if (cls.fteprotocolextensions & FTE_PEXT_TRANS)
+			{
+				if (flags & 0xff0000)
+				{
+					flags |= PF_EXTRA_PFS;
+				}
+				MSG_WriteShort (&cls.demomessage, flags & 0xffff);
+				if (flags & PF_EXTRA_PFS)
+				{
+					MSG_WriteByte(&cls.demomessage, (flags & 0xff0000) >> 16);
+				}
+			}
+			else
+			{
+				// Without PEXT_TRANS there's no PF_EXTRA_PFS, move
+				// PF_ONGROUND and PF_SOLID to their expected offsets.
+				MSG_WriteShort (&cls.demomessage, flags & 0x3fff | (flags & 0xc00000) >> 8);
+			}
+#else
 			MSG_WriteShort(&cls.demomessage, flags);
+#endif
+
 			if (cls.mvdprotocolextensions1 & MVD_PEXT1_FLOATCOORDS) {
 				MSG_WriteLongCoord(&cls.demomessage, state->origin[0]);
 				MSG_WriteLongCoord(&cls.demomessage, state->origin[1]);
