@@ -132,6 +132,10 @@ cvar_t  cl_pext_floatcoords  = {"cl_pext_floatcoords", "1"};
 cvar_t cl_pext_alpha = {"cl_pext_alpha", "1"};
 #endif
 
+#ifdef FTE_PEXT_COLOURMOD
+cvar_t cl_pext_colourmod = {"cl_pext_colourmod", "1"};
+#endif
+
 #ifdef CLIENTONLY
 #define PROCESS_SERVERPACKETS_IMMEDIATELY (0)
 #else
@@ -473,6 +477,10 @@ unsigned int CL_SupportedFTEExtensions (void)
 	if (cl_pext_alpha.value)
 		fteprotextsupported |= FTE_PEXT_TRANS;
 #endif
+#ifdef FTE_PEXT_COLOURMOD
+	if (cl_pext_colourmod.value)
+		fteprotextsupported |= FTE_PEXT_COLOURMOD;
+#endif
 
 	if (cl_pext_limits.value) {
 #ifdef FTE_PEXT_MODELDBL
@@ -723,6 +731,14 @@ void CL_QWURL_f (void)
 		return;
 	}
 
+	// Ensure someone isn't trying to concatenate commands.
+	if (strchr(Cmd_Argv(1), ';') != NULL)
+	{
+		Com_Printf("%s: The QW-URL \"%s\" contains illegal characters\n",
+			Cmd_Argv(0), Cmd_Argv(1));
+		return;
+	}
+
 	// Strip the leading qw:// first.
 	{
 		char qws_str[] = "qw://";
@@ -1871,6 +1887,9 @@ static void CL_InitLocal(void)
 #ifdef FTE_PEXT_TRANS
 	Cvar_Register(&cl_pext_alpha);
 #endif
+#ifdef FTE_PEXT_COLOURMOD
+	Cvar_Register(&cl_pext_colourmod);
+#endif
 
 	Cvar_SetCurrentGroup(CVAR_GROUP_INPUT_KEYBOARD);
 	Cvar_Register(&allow_scripts);
@@ -1913,6 +1932,9 @@ static void CL_InitLocal(void)
 
  	Info_SetValueForStarKey (cls.userinfo, "*client", st, MAX_INFO_STRING);
 
+	snprintf(st, sizeof(st), "ezQuake v%s %s", VERSION_NUMBER, VERSION);
+	Info_SetValueForStarKey(cls.userinfo, "*ver", st, MAX_INFO_STRING);
+
 	if (COM_CheckParm(cmdline_param_client_noindphys))
 	{
 		Cvar_SetValue(&cl_independentPhysics, 0);
