@@ -105,7 +105,12 @@ typedef struct
 
 	int			flags;			// Dead, gib, etc.
 
+#ifdef FTE_PEXT_TRANS
 	byte		alpha;
+#endif
+#ifdef FTE_PEXT_COLOURMOD
+	byte		colourmod[3];
+#endif
 
 	byte		vw_index;
 	byte		pm_type;
@@ -302,7 +307,7 @@ typedef struct {
 	char	map[MAX_STYLESTRING];
 } lightstyle_t;
 
-#define	MAX_STATIC_ENTITIES	512		// torches, etc
+#define	MAX_STATIC_ENTITIES	2048		// torches, etc
 #define	MAX_DEMOS			8
 #define	MAX_DEMONAME		16
 
@@ -795,7 +800,7 @@ typedef struct visentity_s {
 	qbool       draw[visent_max];
 } visentity_t;
 
-#define MAX_STANDARD_ENTITIES 512
+#define MAX_STANDARD_ENTITIES 2048
 
 typedef struct visentlist_s {
 	visentity_t list[MAX_STANDARD_ENTITIES];
@@ -1038,7 +1043,7 @@ void CL_UpdateTEnts(void);
 
 // cl_ents.c
 typedef enum cl_modelindex_s {
-	mi_spike, mi_player, mi_eyes, mi_flag, mi_tf_flag, mi_tf_stan, mi_explod1, mi_explod2, mi_h_player,
+	mi_spike, mi_player, mi_eyes, mi_flag, mi_tf_flag, mi_tf_stan, mi_stag, mi_basrkey, mi_basbkey, mi_w_s_key, mi_w_g_key, mi_b_g_key, mi_b_s_key, mi_ff_flag, mi_harbflag, mi_princess, mi_explod1, mi_explod2, mi_h_player,
 	mi_gib1, mi_gib2, mi_gib3, mi_rocket, mi_grenade, mi_bubble,
 	mi_vaxe, mi_vbio, mi_vgrap, mi_vknife, mi_vknife2, mi_vmedi, mi_vspan,
 	mi_flame,	//joe: for changing flame/flame0 models
