@@ -31,6 +31,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "parser.h"
 #include "utils.h"
 #include "keys.h"
+#include "hash.h"
 #include <pcre2.h>
 
 typedef struct {
@@ -57,6 +58,22 @@ cvar_t cl_warncmd = {"cl_warncmd", "1"};
 cvar_t cl_warnexec = {"cl_warnexec", "1"};
 cvar_t cl_curlybraces = {"cl_curlybraces", "0"};
 
+#define REMOTE_CAPABILITIES "+attack,-attack,alias,bf,changing,cmd,color,download,exec,fullserverinfo," \
+				"impulse,infoset,ktx_infoset,ktx_sinfoset,nextul,on_admin,on_connect," \
+				"on_connect_ctf,on_connect_ffa,on_enter,on_enter_ctf,on_enter_ffa,on_matchend," \
+				"on_matchstart,on_observe,on_observe_ctf,on_observe_ffa,on_spec_enter," \
+				"on_spec_enter_ctf,on_spec_enter_ffa,on_spec_matchend,on_spec_matchstart," \
+				"on_unadmin,packet,play,rate,reconnect,say,sinfoset,skin,skins,team,tempalias," \
+				"track,wait"
+
+static void OnChange_remote_capabilities(cvar_t *var, char *string, qbool *cancel);
+cvar_t cl_remote_capabilities = {"cl_remote_capabilities", REMOTE_CAPABILITIES, 0,
+				   OnChange_remote_capabilities};
+hashtable_t *rc_hash;
+
+cvar_t cl_allow_downloads = {"cl_allow_downloads", "bsp,lmp,loc,mdl,mvd,pcx,spr,wad,wav"};
+cvar_t cl_allow_uploads = {"cl_allow_uploads", "0"};
+
 cbuf_t cbuf_main;
 cbuf_t cbuf_svc;
 cbuf_t cbuf_safe, cbuf_formatted_comms;
@@ -64,6 +81,86 @@ cbuf_t cbuf_server;
 
 cbuf_t *cbuf_current = NULL;
 
+static void OnChange_remote_capabilities(cvar_t *var, char *string, qbool *cancel)
+{
+	char *cmd, *ent, *tmp;
+
+	if (cls.state != ca_disconnected)
+	{
+		Com_Printf("You cannot change remote capabilities unless you are disconnected\n");
+		return;
+	}
+
+	if (!rc_hash || strlen(var->string) == 0)
+	{
+		goto add;
+	}
+
+	tmp = Q_strdup(var->string);
+	cmd = strtok(tmp, ",");
+	while (cmd != NULL)
+	{
+		Com_DPrintf("Removing %s from remote capabilities\n", cmd);
+
+		if ((ent = Hash_Get(rc_hash, cmd)))
+		{
+			Q_free(ent);
+			Hash_Remove(rc_hash, cmd);
+		}
+
+		cmd = strtok(NULL, ",");
+	}
+	Q_free(tmp);
+
+add:
+	if (!rc_hash)
+	{
+		rc_hash = Hash_InitTable(512);
+	}
+	else
+	{
+		Hash_Flush(rc_hash);
+	}
+
+	tmp = Q_strdup(string);
+	cmd = strtok(tmp, ",");
+	while (cmd != NULL)
+	{
+		Com_DPrintf("Adding %s to capabilities\n", cmd);
+
+		if (!Hash_Get(rc_hash, cmd))
+		{
+			ent = Q_malloc(sizeof(char));
+			*ent = 1;
+			Hash_Add(rc_hash, cmd, (void *)ent);
+		}
+
+		cmd = strtok(NULL, ",");
+	}
+	Q_free(tmp);
+}
+
+qbool CL_IsDownloadableFileExtension(const char *filename)
+{
+	qbool is_allowed = false;
+	char *ext, *str, *tmp;
+
+	ext = COM_FileExtension(filename);
+	str = Q_strdup(cl_allow_downloads.string);
+	tmp = strtok(str, ",");
+	while (tmp != NULL) {
+		if (strcmp(ext, tmp) == 0) {
+			is_allowed = true;
+			break;
+		}
+
+		tmp = strtok(NULL, ",");
+	}
+	Q_free(str);
+
+	return is_allowed;
+}
+
 //=============================================================================
 
 //Causes execution of the remainder of the command buffer to be delayed until next frame.
@@ -120,7 +217,7 @@ static void Cbuf_Register (cbuf_t *cbuf, int maxsize)
 {
 	assert (!host_initialized);
 	cbuf->maxsize = maxsize;
-	cbuf->text_buf = (char *) Hunk_Alloc(maxsize);
+	cbuf->text_buf = (char *) Hunk_AllocName(maxsize, "cbuf");
 	cbuf->text_start = cbuf->text_end = (cbuf->maxsize >> 1);
 	cbuf->wait = false;
 	cbuf->waitCount = 0;
@@ -458,6 +555,11 @@ void Cmd_Exec_f (void)
 	char reset_bindphysical[128];
 	qbool server_command = false;
 
+	if (Rulesets_RestrictExec()) {
+		Com_Printf("The use of exec is not allowed during matches\n");
+		return;
+	}
+
 	if (Cmd_Argc () != 2) {
 		Com_Printf ("%s <filename> : execute a script file\n", Cmd_Argv(0));
 		return;
@@ -467,6 +569,11 @@ void Cmd_Exec_f (void)
 	server_command = cbuf_current == &cbuf_server || !strcmp(Cmd_Argv(0), "serverexec");
 #endif
 
+	if (CL_IsDownloadableFileExtension(Cmd_Argv(1))) {
+		Com_Printf("Warning: \"%s\" is not allowed to be executed. Remove \"%s\" from cl_allow_downloads to allow execution\n", Cmd_Argv(1), COM_FileExtension(Cmd_Argv(1)));
+		return;
+	}
+
 	strlcpy (name, Cmd_Argv(1), sizeof(name) - 4);
 	if (!(f = (char *) FS_LoadHeapFile(name, NULL)))	{
 		const char *p;
@@ -1180,7 +1287,7 @@ void Cmd_AddCommand (char *cmd_name, xcommand_t function)
 		}
 	}
 
-	cmd = (cmd_function_t *) Hunk_Alloc (sizeof(cmd_function_t));
+	cmd = (cmd_function_t *) Hunk_AllocName (sizeof(cmd_function_t), "cmd");
 	cmd->name = cmd_name;
 	cmd->function = function;
 	cmd->zmalloced = false;
@@ -1653,7 +1760,7 @@ int Commands_Compare_Func (const void * arg1, const void * arg2)
 }
 
 char *msgtrigger_commands[] = {
-	"play", "playvol", "stopsound", "set", "echo", "say", "say_team",
+	"play", "playvol", "stopsound", "stopsound_script", "set", "echo", "say", "say_team",
 	"alias", "unalias", "msg_trigger", "inc", "bind", "unbind", "record",
 	"easyrecord", "stop", "if", "if_exists", "wait", "log", "match_forcestart",
 	"dns", "addserver", "connect", "join", "observe",
@@ -1742,6 +1849,7 @@ static void Cmd_ExecuteStringEx (cbuf_t *context, char *text)
 	cbuf_t *inserttarget, *oldcontext;
 	char *p, *n, *s;
 	char text_exp[1024];
+	qbool is_server_alias = false;
 
 	oldcontext = cbuf_current;
 	cbuf_current = context;
@@ -1778,10 +1886,17 @@ static void Cmd_ExecuteStringEx (cbuf_t *context, char *text)
 			}
 		}
 
-		if (cmd->function)
+		if (cmd->function) {
+			if (cbuf_current == &cbuf_svc && !Hash_Get(rc_hash, cmd->name)) {
+				Com_Printf("Blocked %s: not in cl_remote_capabilities\n", cmd->name);
+				goto done;
+			}
+
 			cmd->function();
-		else
+		}
+		else {
 			Cmd_ForwardToServer ();
+		}
 		goto done;
 	}
 
@@ -1791,6 +1906,11 @@ static void Cmd_ExecuteStringEx (cbuf_t *context, char *text)
 
 	// check cvars
 	if ((v = Cvar_Find(Cmd_Argv(0)))) {
+		if (cbuf_current == &cbuf_svc && !Hash_Get(rc_hash, v->name)) {
+			Com_Printf("Blocked %s: not in cl_remote_capabilities\n", v->name);
+			goto done;
+		}
+
 		if (cbuf_current == &cbuf_formatted_comms) {
 			Com_Printf ("\"%s\" cannot be used in combination with teamplay $macros\n", Cmd_Argv(0));
 			goto done;
@@ -1802,6 +1922,7 @@ static void Cmd_ExecuteStringEx (cbuf_t *context, char *text)
 	// check aliases
 checkaliases:
 	if ((a = Cmd_FindAlias(Cmd_Argv(0)))) {
+		is_server_alias = a->flags & ALIAS_SERVER;
 
 		// QW262 -->
 		if (a->value[0] == '\0') {
@@ -1851,11 +1972,16 @@ checkaliases:
 
 		if (cbuf_current == &cbuf_svc)
 		{
-			Cbuf_AddText (p);
-			Cbuf_AddText ("\n");
+			inserttarget = is_server_alias ? &cbuf_svc : &cbuf_main;
+			Cbuf_AddTextEx (inserttarget, p);
+			Cbuf_AddTextEx (inserttarget, "\n");
 		} else
 		{
-			inserttarget = cbuf_current ? cbuf_current : &cbuf_main;
+			if (is_server_alias)
+				inserttarget = &cbuf_svc;
+			else
+				inserttarget = cbuf_current ? cbuf_current : &cbuf_main;
+
 			Cbuf_InsertTextEx (inserttarget, "\n");
 
 			// if the alias value is a command or cvar and
@@ -2403,7 +2529,10 @@ void Cmd_Init (void)
 // <-- QW262
 
 	Cvar_Register(&cl_curlybraces);
-    Cvar_Register(&cl_warnexec);
+	Cvar_Register(&cl_warnexec);
+	Cvar_Register(&cl_remote_capabilities);
+	Cvar_Register(&cl_allow_downloads);
+	Cvar_Register(&cl_allow_uploads);
 
 	Cmd_AddCommand ("macrolist", Cmd_MacroList_f);
 	qsort(msgtrigger_commands,
