@@ -246,7 +246,7 @@ static qbool FontCreate(int grouping, const char* userpath)
 	strlcpy(path, Sys_FontsDirectory(), sizeof(path));
 	strlcat(path, "/", sizeof(path));
 	strlcat(path, userpath, sizeof(path));
-	COM_DefaultExtension(path, ".ttf");
+	COM_DefaultExtension(path, ".ttf", sizeof(path));
 
 	error = ezFT_New_Face(library, path, 0, &face);
 	if (error == FT_Err_Unknown_File_Format) {
@@ -474,7 +474,7 @@ void Draw_ListFonts_f(void)
 		}
 		if (regexp) {
 			match_data = pcre2_match_data_create_from_pattern(regexp, NULL);
-			if (pcre2_match(regexp, (PCRE2_SPTR)dir.files[i].name, strlen(dir.files[i].name), 0, 0, match_data, NULL) <= 0) {
+			if (pcre2_match(regexp, (PCRE2_SPTR)dir.files[i].name, strlen(dir.files[i].name), 0, 0, match_data, NULL) < 0) {
 				pcre2_match_data_free(match_data);
 				continue;
 			}
