@@ -56,9 +56,7 @@ extern cvar_t r_farclip, gl_max_size, gl_miptexLevel;
 extern cvar_t r_bloom;
 extern cvar_t gl_flashblend, r_dynamic, gl_lightmode, gl_modulate;
 
-#ifdef RENDERER_OPTION_MODERN_OPENGL
-extern cvar_t vid_framebuffer, vid_framebuffer_hdr, vid_framebuffer_hdr_tonemap, vid_framebuffer_scale, vid_framebuffer_multisample;
-#endif
+extern cvar_t vid_framebuffer, vid_framebuffer_hdr, vid_framebuffer_hdr_tonemap, vid_framebuffer_scale, vid_framebuffer_multisample, vid_framebuffer_fxaa;
 
 extern cvar_t vid_software_palette;
 
@@ -248,7 +246,7 @@ const char* s_desired_samples_enum[] = {
 };
 
 const char* cl_nolerp_enum[] = {"on", "off"};
-const char* ruleset_enum[] = { "ezQuake default", "default", "Smackdown", "smackdown", "Thunderdome", "thunderdome", "Moscow TF League", "mtfl", "QuakeCon", "qcon" };
+const char* ruleset_enum[] = { "ezQuake default", "default", "Smackdown", "smackdown", "Thunderdome", "thunderdome", "Moscow TF League", "mtfl", "QuakeCon", "qcon", "Smackdrive", "smackdrive" };
 const char *mediaroot_enum[] = { "relative to exe", "relative to home", "full path" };
 const char *teamforceskins_enum[] = { "off", "use player's name", "use player's userid", "set t1, t2, t3, ..." };
 const char *enemyforceskins_enum[] = { "off", "use player's name", "use player's userid", "set e1, e2, e3, ..." };
@@ -434,13 +432,11 @@ const char* vid_renderer_enum[] = {
 };
 #endif
 
-#ifdef RENDERER_OPTION_MODERN_OPENGL
 const char* vid_framebuffer_enum[] = {
 	"disabled", "0",
 	"enabled", "1",
 	"enabled (separate scene & hud)", "2"
 };
-#endif
 
 settings_page settfps;
 
@@ -522,13 +518,11 @@ void VideoApplySettings (void)
 	mss_askmode = true;
 }
 
-#if defined(EZ_MULTIPLE_RENDERERS) || defined(RENDERER_OPTION_MODERN_OPENGL)
 // performed when user hits the "apply" button
 void RendererRestart (void)
 {
 	Cbuf_AddText("vid_restart\n");
 }
-#endif
 
 // two possible results of the "keep these video settings?" dialogue
 static void KeepNewVideoSettings (void) { mss_askmode = false; }
@@ -1299,7 +1293,6 @@ setting settsystem_arr[] = {
 	ADDSET_ACTION("Apply Changes", RendererRestart, "Restarts the renderer."),
 #endif
 
-#ifdef RENDERER_OPTION_MODERN_OPENGL
 	ADDSET_ADVANCED_SECTION(),
 	ADDSET_SEPARATOR("Framebuffer"),
 	ADDSET_ENUM("Mode", vid_framebuffer, vid_framebuffer_enum),
@@ -1307,9 +1300,9 @@ setting settsystem_arr[] = {
 	ADDSET_BOOL("HDR Tonemap", vid_framebuffer_hdr_tonemap),
 	ADDSET_NUMBER("Scale", vid_framebuffer_scale, 0.25, 2.0, 0.25),
 	ADDSET_NUMBER("Multisample", vid_framebuffer_multisample, 0, 16, 1),
+	ADDSET_NUMBER("FXAA", vid_framebuffer_fxaa, 0, 17, 1),
 	ADDSET_ACTION("Apply Changes", RendererRestart, "Restarts the renderer."),
 	ADDSET_BASIC_SECTION(),
-#endif
 
 	//Font
 	ADDSET_ADVANCED_SECTION(),
