@@ -46,8 +46,7 @@ void Mod_AddModelFlags(model_t *mod);
 
 byte	mod_novis[MAX_MAP_LEAFS/8];
 
-#define	MAX_MOD_KNOWN	512
-model_t	mod_known[MAX_MOD_KNOWN];
+model_t	mod_known[MAX_MODELS];
 int		mod_numknown;
 
 void Mod_Init(void)
@@ -175,7 +174,7 @@ model_t *Mod_FindName(const char *name)
 	}
 
 	if (i == mod_numknown) {
-		if (mod_numknown == MAX_MOD_KNOWN) {
+		if (mod_numknown == MAX_MODELS) {
 			Sys_Error("mod_numknown == MAX_MOD_KNOWN");
 		}
 		strlcpy(mod->name, name, sizeof(mod->name));
@@ -261,7 +260,7 @@ model_t *Mod_LoadModel(model_t *mod, qbool crash)
 		(namelen >= 9 && mod->name[5] == 'b' && mod->name[6] == '_' && !strcmp(mod->name + namelen - 4, ".bsp")))) {
 		char newname[MAX_QPATH];
 		COM_StripExtension(mod->name, newname, sizeof(newname));
-		COM_DefaultExtension(newname, ".md3");
+		COM_DefaultExtension(newname, ".md3", sizeof(newname));
 		buf = (unsigned *)FS_LoadTempFile(newname, &filesize);
 	}
 
@@ -465,6 +464,12 @@ void Mod_AddModelFlags(model_t *mod)
 		!strcmp(mod->name, "progs/w_s_key.mdl") ||
 		!strcmp(mod->name, "progs/b_g_key.mdl") ||
 		!strcmp(mod->name, "progs/b_s_key.mdl") ||
+		!strcmp(mod->name, "progs/stag.mdl") ||
+		!strcmp(mod->name, "progs/basrkey.bsp") ||
+		!strcmp(mod->name, "progs/basbkey.bsp") ||
+		!strcmp(mod->name, "progs/ff_flag.mdl") ||
+		!strcmp(mod->name, "progs/harbflag.mdl") ||
+		!strcmp(mod->name, "progs/princess.mdl") ||
 		!strcmp(mod->name, "progs/tf_stan.mdl")) {
 		mod->modhint = MOD_FLAG;
 	}
