@@ -114,6 +114,15 @@ static void OnDynamicLightingChange(cvar_t* var, char* value, qbool* cancel)
 	}
 }
 
+static void OnRemoveCollinearVerticesChanged(cvar_t* var, char* value, qbool* cancel)
+{
+#if defined(__APPLE__) && defined(__aarch64__)
+	// At least arm64 based MacBook laptops are known to require this workaround.
+	Cvar_SetIgnoreCallback(var, "1");
+	*cancel = true;
+#endif
+}
+
 cvar_t cl_multiview                        = {"cl_multiview", "0" };
 cvar_t cl_mvdisplayhud                     = {"cl_mvdisplayhud", "1"};
 cvar_t cl_mvhudvertical                    = {"cl_mvhudvertical", "0"};
@@ -160,6 +169,7 @@ cvar_t r_floorcolor                        = {"r_floorcolor", "50 100 150", CVAR
 cvar_t gl_textureless                      = {"gl_textureless", "0", 0, OnChange_r_drawflat}; //Qrack
 cvar_t r_farclip                           = {"r_farclip", "8192", CVAR_RULESET_MAX | CVAR_RULESET_MIN, NULL, 8192.0f, R_MAXIMUM_FARCLIP, R_MINIMUM_FARCLIP }; // previous default was 4096. 8192 helps some TF players in big maps
 cvar_t r_skyname                           = {"r_skyname", "", 0, OnChange_r_skyname};
+cvar_t r_skywind                           = {"r_skywind", "1"};
 cvar_t gl_detail                           = {"gl_detail","0"};
 cvar_t gl_brush_polygonoffset              = {"gl_brush_polygonoffset", "2.0"}; // This is the one to adjust if you notice flicker on lift @ e1m1 for instance, for z-fighting
 cvar_t gl_brush_polygonoffset_factor       = {"gl_brush_polygonoffset_factor", "0.05"};
@@ -182,6 +192,7 @@ cvar_t gl_oldlitscaling                    = {"gl_oldlitscaling", "0"};
 cvar_t gl_colorlights                      = {"gl_colorlights", "1"};
 cvar_t gl_squareparticles                  = {"gl_squareparticles", "0", 0, OnSquareParticleChange};
 cvar_t gl_part_explosions                  = {"gl_part_explosions", "0"}; // 1
+cvar_t gl_part_bloodtrails                 = {"gl_part_bloodtrails", "1"}; // 1 was the default behaviour before this became a cvar
 cvar_t gl_part_trails                      = {"gl_part_trails", "0"}; // 1
 cvar_t gl_part_tracer1_color               = {"gl_part_tracer1_color", "0 124 0", CVAR_COLOR};
 cvar_t gl_part_tracer2_color               = {"gl_part_tracer2_color", "255 77 0", CVAR_COLOR};
@@ -226,6 +237,7 @@ cvar_t gl_outline_color_model              = {"gl_outline_color_model", "0 0 0"}
 cvar_t gl_outline_scale_world              = {"gl_outline_scale_world", "1"};
 cvar_t gl_outline_scale_model              = {"gl_outline_scale_model", "1"};
 cvar_t gl_outline_world_depth_threshold    = {"gl_outline_world_depth_threshold", "4"};
+cvar_t gl_outline_world_normal_threshold   = {"gl_outline_world_normal_threshold", "0.997"};
 cvar_t gl_outline_use_player_color         = {"gl_outline_use_player_color", "0"};
 cvar_t gl_spec_xray                        = {"gl_spec_xray", "0"};
 cvar_t gl_spec_xray_distance               = {"gl_spec_xray_distance", "1500"};
@@ -236,6 +248,8 @@ cvar_t gl_smoothmodels                     = {"gl_smoothmodels", "1"};
 
 cvar_t gl_vbo_clientmemory                 = {"gl_vbo_clientmemory", "0", CVAR_LATCH_GFX };
 
+cvar_t r_remove_collinear_vertices         = {"r_remove_collinear_vertices", "0", 0, OnRemoveCollinearVerticesChanged};
+
 //Returns true if the box is completely outside the frustom
 qbool R_CullBox(vec3_t mins, vec3_t maxs)
 {
@@ -589,7 +603,7 @@ static void R_SetupGL(void)
 
 void R_Init(void)
 {
-	Cmd_AddCommand("loadsky", R_LoadSky_f);
+	R_SkyRegisterCvars();
 	Cmd_AddCommand("timerefresh", R_TimeRefresh_f);
 #ifndef CLIENTONLY
 	Cmd_AddCommand("dev_pointfile", R_ReadPointFile_f);
@@ -618,6 +632,7 @@ void R_Init(void)
 
 	Cvar_SetCurrentGroup(CVAR_GROUP_PARTICLES);
 	Cvar_Register(&gl_part_explosions);
+	Cvar_Register(&gl_part_bloodtrails);
 	Cvar_Register(&gl_part_trails);
 	Cvar_Register(&gl_part_tracer1_color);
 	Cvar_Register(&gl_part_tracer1_size);
@@ -640,6 +655,7 @@ void R_Init(void)
 
 	Cvar_SetCurrentGroup(CVAR_GROUP_TURB);
 	Cvar_Register(&r_skyname);
+	Cvar_Register(&r_skywind);
 	Cvar_Register(&r_fastsky);
 	Cvar_Register(&r_skycolor);
 	Cvar_Register(&r_fastturb);
@@ -714,6 +730,7 @@ void R_Init(void)
 	// Cvar_Register(&gl_outline_scale_world);
 	Cvar_Register(&gl_outline_scale_model);
 	Cvar_Register(&gl_outline_world_depth_threshold);
+	Cvar_Register(&gl_outline_world_normal_threshold);
 	Cvar_Register(&gl_outline_use_player_color);
 	Cvar_Register(&gl_spec_xray);
 	Cvar_Register(&gl_spec_xray_distance);
@@ -746,6 +763,8 @@ void R_Init(void)
 	Cvar_Register(&cl_mvinset_top);
 	Cvar_Register(&cl_mvinset_right);
 
+	Cvar_Register(&r_remove_collinear_vertices);
+
 	Cvar_ResetCurrentGroup();
 
 	if (!hud_netgraph) {
@@ -869,18 +888,11 @@ void R_RenderView(void)
 	// render normal view
 	R_DrawWorld();		// adds static entities to the list
 
-	if (r_refdef2.wateralpha == 1) {
-		renderer.DrawWaterSurfaces();
-	}
-
 	R_DrawEntities();
 
 	// Adds 3d effects (particles, lights, chat icons etc)
 	R_Render3DEffects();
 
-	// Draws transparent world surfaces
-	renderer.DrawWaterSurfaces();
-
 	// Render billboards
 	renderer.Draw3DSpritesInline();
 
@@ -1045,7 +1057,7 @@ static void R_DrawEntitiesOnList(visentlist_t *vislist, visentlist_entrytype_t t
 {
 	int i;
 
-	if (r_drawentities.integer && vislist->typecount[type] >= 0) {
+	if (r_drawentities.integer && vislist->typecount[type] > 0) {
 		for (i = 0; i < vislist->count; i++) {
 			visentity_t* todraw = &vislist->list[i];
 
@@ -1124,6 +1136,10 @@ static void R_DrawEntities(void)
 	R_Sprite3DInitialiseBatch(SPRITE3D_ENTITIES, r_state_sprites_textured, null_texture_reference, 0, r_primitive_triangle_strip);
 	qsort(cl_visents.list, cl_visents.count, sizeof(cl_visents.list[0]), R_DrawEntitiesSorter);
 	for (ent_type = 0; ent_type < visent_max; ++ent_type) {
+		if (ent_type == visent_alpha) {
+			// Transluscent before translucent entities, but after opaque ones.
+			renderer.DrawWaterSurfaces();
+		}
 		R_DrawEntitiesOnList(&cl_visents, ent_type);
 	}
 	if (R_UseModernOpenGL() || R_UseVulkan()) {
