@@ -36,6 +36,11 @@ typedef struct rulesetDef_s {
 	qbool restrictSound;
 	qbool restrictLogging;
 	qbool restrictRollAngle;
+	qbool restrictIPC;
+	qbool restrictExec;
+	qbool restrictSetCalc;
+	qbool restrictSetEval;
+	qbool restrictSetEx;
 } rulesetDef_t;
 
 static rulesetDef_t rulesetDef = {
@@ -46,7 +51,12 @@ static rulesetDef_t rulesetDef = {
 	false,         // restrict particles
 	false,         // restrict sound
 	false,         // restrict logging
-	false          // restrict rollangle
+	false,         // restrict rollangle
+	false,         // restrict IPC
+	false,         // restrict /exec command
+	false,         // restrict /set_calc command
+	false,         // restrict /set_eval command
+	false          // restrict /set_ex command
 };
 
 cvar_t ruleset = {"ruleset", "default", 0, Rulesets_OnChange_ruleset};
@@ -57,7 +67,7 @@ qbool RuleSets_DisallowExternalTexture(struct model_s *mod)
 		case MOD_EYES:
 			return true;
 		case MOD_BACKPACK:
-			return rulesetDef.ruleset == rs_smackdown || rulesetDef.ruleset == rs_qcon;
+			return rulesetDef.ruleset == rs_smackdown || rulesetDef.ruleset == rs_qcon || rulesetDef.ruleset == rs_smackdrive;
 		default:
 			return false;
 	}
@@ -74,7 +84,7 @@ qbool RuleSets_DisallowSimpleTexture(model_t* mod)
 
 		case MOD_BACKPACK:
 			// Now allowed in Thunderdome...
-			return rulesetDef.ruleset == rs_smackdown || rulesetDef.ruleset == rs_qcon;
+			return rulesetDef.ruleset == rs_smackdown || rulesetDef.ruleset == rs_qcon || rulesetDef.ruleset == rs_smackdrive;
 
 		default:
 			return false; // replacement always allowed
@@ -94,10 +104,10 @@ qbool RuleSets_DisallowModelOutline(struct model_s *mod)
 		case MOD_THUNDERBOLT:
 			return true;
 		case MOD_BACKPACK:
-			return !cls.demoplayback && (rulesetDef.ruleset == rs_qcon || rulesetDef.ruleset == rs_smackdown);
+			return !cls.demoplayback && (rulesetDef.ruleset == rs_qcon || rulesetDef.ruleset == rs_smackdown || rulesetDef.ruleset == rs_smackdrive);
 		default:
 			// return to just rs_qcon once backface outlining tested
-//			return !cls.demoplayback && (rulesetDef.ruleset == rs_qcon || rulesetDef.ruleset == rs_smackdown);
+//			return !cls.demoplayback && (rulesetDef.ruleset == rs_qcon || rulesetDef.ruleset == rs_smackdown || rulesetDef.ruleset == rs_smackdrive);
 			return !cls.demoplayback && (rulesetDef.ruleset == rs_qcon);
 	}
 }
@@ -108,6 +118,7 @@ float RuleSets_ModelOutlineScale(void) {
 	extern cvar_t gl_outline_scale_model;
 	switch(rulesetDef.ruleset) {
 		case rs_smackdown:
+		case rs_smackdrive:
 		case rs_qcon:
 			return bound(0.0f, gl_outline_scale_model.value, 1.0f);
 		default:
@@ -130,6 +141,7 @@ qbool Rulesets_AllowTimerefresh(void)
 {
 	switch(rulesetDef.ruleset) {
 		case rs_smackdown:
+		case rs_smackdrive:
 		case rs_thunderdome:
 		case rs_qcon:
 			return (cl.standby || cl.spectator || cls.demoplayback);
@@ -143,6 +155,7 @@ qbool Rulesets_AllowNoShadows(void)
 	switch(rulesetDef.ruleset) {
 		case rs_mtfl:
 		case rs_smackdown:
+		case rs_smackdrive:
 		case rs_thunderdome:
 		case rs_qcon:
 			return false;
@@ -200,10 +213,36 @@ qbool Rulesets_RestrictParticles(void)
 	return !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictParticles && !r_refdef2.allow_cheats;
 }
 
+qbool Rulesets_RestrictIPC(void)
+{
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictIPC;
+}
+
+qbool Rulesets_RestrictExec(void)
+{
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictExec;
+}
+
+qbool Rulesets_RestrictSetCalc(void)
+{
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictSetCalc;
+}
+
+qbool Rulesets_RestrictSetEval(void)
+{
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictSetEval;
+}
+
+qbool Rulesets_RestrictSetEx(void)
+{
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictSetEx;
+}
+
 qbool Rulesets_RestrictTCL(void)
 {
 	switch(rulesetDef.ruleset) {
 		case rs_smackdown:
+		case rs_smackdrive:
 		case rs_thunderdome:
 		case rs_qcon:
 			return true;
@@ -224,6 +263,8 @@ const char *Rulesets_Ruleset(void)
 			return "thunderdome";
 		case rs_qcon:
 			return "qcon";
+		case rs_smackdrive:
+			return "smackdrive";
 		default:
 			return "default";
 	}
@@ -268,6 +309,11 @@ static void Rulesets_Smackdown(qbool enable)
 		rulesetDef.restrictLogging = true;
 		rulesetDef.restrictRollAngle = true;
 		rulesetDef.ruleset = rs_smackdown;
+		rulesetDef.restrictIPC = true;
+		rulesetDef.restrictExec = true;
+		rulesetDef.restrictSetCalc = true;
+		rulesetDef.restrictSetEval = true;
+		rulesetDef.restrictSetEx = true;
 	} else {
 		for (i = 0; i < (sizeof(disabled_cvars) / sizeof(disabled_cvars[0])); i++)
 			Cvar_SetFlags(disabled_cvars[i].var, Cvar_GetFlags(disabled_cvars[i].var) & ~CVAR_ROM);
@@ -282,6 +328,11 @@ static void Rulesets_Smackdown(qbool enable)
 		rulesetDef.restrictLogging = false;
 		rulesetDef.restrictRollAngle = false;
 		rulesetDef.ruleset = rs_default;
+		rulesetDef.restrictIPC = false;
+		rulesetDef.restrictExec = false;
+		rulesetDef.restrictSetCalc = false;
+		rulesetDef.restrictSetEval = false;
+		rulesetDef.restrictSetEx = false;
 	}
 }
 
@@ -323,6 +374,11 @@ static void Rulesets_Qcon(qbool enable)
 		rulesetDef.restrictLogging = true;
 		rulesetDef.restrictRollAngle = true;
 		rulesetDef.ruleset = rs_qcon;
+		rulesetDef.restrictIPC = true;
+		rulesetDef.restrictExec = true;
+		rulesetDef.restrictSetCalc = true;
+		rulesetDef.restrictSetEval = true;
+		rulesetDef.restrictSetEx = true;
 	} else {
 		for (i = 0; i < (sizeof(disabled_cvars) / sizeof(disabled_cvars[0])); i++)
 			Cvar_SetFlags(disabled_cvars[i].var, Cvar_GetFlags(disabled_cvars[i].var) & ~CVAR_ROM);
@@ -338,6 +394,11 @@ static void Rulesets_Qcon(qbool enable)
 		rulesetDef.restrictLogging = false;
 		rulesetDef.restrictRollAngle = false;
 		rulesetDef.ruleset = rs_default;
+		rulesetDef.restrictIPC = false;
+		rulesetDef.restrictExec = false;
+		rulesetDef.restrictSetCalc = false;
+		rulesetDef.restrictSetEval = false;
+		rulesetDef.restrictSetEx = false;
 	}
 }
 static void Rulesets_Thunderdome(qbool enable)
@@ -375,6 +436,11 @@ static void Rulesets_Thunderdome(qbool enable)
 		rulesetDef.restrictLogging = true;
 		rulesetDef.restrictRollAngle = true;
 		rulesetDef.ruleset = rs_thunderdome;
+		rulesetDef.restrictIPC = true;
+		rulesetDef.restrictExec = true;
+		rulesetDef.restrictSetCalc = true;
+		rulesetDef.restrictSetEval = true;
+		rulesetDef.restrictSetEx = true;
 	} else {
 		for (i = 0; i < (sizeof(disabled_cvars) / sizeof(disabled_cvars[0])); i++)
 			Cvar_SetFlags(disabled_cvars[i].var, Cvar_GetFlags(disabled_cvars[i].var) & ~CVAR_ROM);
@@ -389,6 +455,11 @@ static void Rulesets_Thunderdome(qbool enable)
 		rulesetDef.restrictLogging = false;
 		rulesetDef.restrictRollAngle = false;
 		rulesetDef.ruleset = rs_default;
+		rulesetDef.restrictIPC = false;
+		rulesetDef.restrictExec = false;
+		rulesetDef.restrictSetCalc = false;
+		rulesetDef.restrictSetEval = false;
+		rulesetDef.restrictSetEx = false;
 	}
 }
 static void Rulesets_MTFL(qbool enable)
@@ -459,6 +530,70 @@ static void Rulesets_MTFL(qbool enable)
 	}
 }
 
+static void Rulesets_Smackdrive(qbool enable)
+{
+	extern cvar_t cl_independentPhysics, cl_c2spps;
+	extern cvar_t cl_hud;
+	extern cvar_t cl_rollalpha;
+	extern cvar_t r_shiftbeam;
+	extern cvar_t allow_scripts;
+	extern cvar_t scr_allowsnap;
+	int i;
+
+	locked_cvar_t disabled_cvars[] = {
+		{&allow_scripts, "0"},  // disable movement scripting
+		{&cl_hud, "0"},         // allows you place any text on the screen & filter incoming messages (hud strings)
+		{&cl_rollalpha, "20"},  // allows you to not dodge while seeing enemies dodging
+		{&r_shiftbeam, "0"},    // perphaps some people would think this allows you to aim better (maybe should be added for demo playback and spectating only)
+		{&scr_allowsnap, "1"}
+	};
+
+	if (enable) {
+		for (i = 0; i < (sizeof(disabled_cvars) / sizeof(disabled_cvars[0])); i++) {
+			Cvar_RulesetSet(disabled_cvars[i].var, disabled_cvars[i].value, 2);
+			Cvar_Set(disabled_cvars[i].var, disabled_cvars[i].value);
+			Cvar_SetFlags(disabled_cvars[i].var, Cvar_GetFlags(disabled_cvars[i].var) | CVAR_ROM);
+		}
+
+		if (cl_independentPhysics.value) {
+			Cvar_Set(&cl_c2spps, "0"); // people were complaining that player move is jerky with this. however this has not much to do with independent physics, but people are too paranoid about it
+			Cvar_SetFlags(&cl_c2spps, Cvar_GetFlags(&cl_c2spps) | CVAR_ROM);
+		}
+
+		rulesetDef.maxfps = 77;
+		rulesetDef.restrictTriggers = true;
+		rulesetDef.restrictPacket = true; // packet command could have been exploited for external timers
+		rulesetDef.restrictParticles = true;
+		rulesetDef.restrictLogging = true;
+		rulesetDef.restrictRollAngle = true;
+		rulesetDef.ruleset = rs_smackdrive;
+		rulesetDef.restrictIPC = true;
+		rulesetDef.restrictExec = true;
+		rulesetDef.restrictSetCalc = true;
+		rulesetDef.restrictSetEval = true;
+		rulesetDef.restrictSetEx = true;
+	} else {
+		for (i = 0; i < (sizeof(disabled_cvars) / sizeof(disabled_cvars[0])); i++)
+			Cvar_SetFlags(disabled_cvars[i].var, Cvar_GetFlags(disabled_cvars[i].var) & ~CVAR_ROM);
+
+		if (cl_independentPhysics.value)
+			Cvar_SetFlags(&cl_c2spps, Cvar_GetFlags(&cl_c2spps) & ~CVAR_ROM);
+
+		rulesetDef.maxfps = 72.0;
+		rulesetDef.restrictTriggers = false;
+		rulesetDef.restrictPacket = false;
+		rulesetDef.restrictParticles = false;
+		rulesetDef.restrictLogging = false;
+		rulesetDef.restrictRollAngle = false;
+		rulesetDef.ruleset = rs_default;
+		rulesetDef.restrictIPC = false;
+		rulesetDef.restrictExec = false;
+		rulesetDef.restrictSetCalc = false;
+		rulesetDef.restrictSetEval = false;
+		rulesetDef.restrictSetEx = false;
+	}
+}
+
 static void Rulesets_Default(void)
 {
 	rulesetDef.ruleset = rs_default;
@@ -670,6 +805,7 @@ static void Rulesets_OnChange_ruleset(cvar_t *var, char *value, qbool *cancel)
 			strncasecmp(value, "thunderdome", sizeof("thunderdome")) &&
 			strncasecmp(value, "mtfl", sizeof("mtfl")) &&
 			strncasecmp(value, "qcon", sizeof("qcon")) &&
+			strncasecmp(value, "smackdrive", sizeof("smackdrive")) &&
 			strncasecmp(value, "default", sizeof("default"))) {
 		Com_Printf_State(PRINT_INFO, "Unknown ruleset \"%s\"\n", value);
 		*cancel = true;
@@ -690,6 +826,8 @@ static void Rulesets_OnChange_ruleset(cvar_t *var, char *value, qbool *cancel)
 		case rs_thunderdome:
 			Rulesets_Thunderdome(false);
 			break;
+		case rs_smackdrive:
+			Rulesets_Smackdrive(false);
 		case rs_default:
 			break;
 		default:
@@ -711,6 +849,9 @@ static void Rulesets_OnChange_ruleset(cvar_t *var, char *value, qbool *cancel)
 	} else if (!strncasecmp(value, "qcon", sizeof("qcon"))) {
 		Rulesets_Qcon(true);
 		Com_Printf_State(PRINT_OK, "Ruleset Qcon initialized\n");
+	} else if (!strncasecmp(value, "smackdrive", sizeof("smackdrive"))) {
+		Rulesets_Smackdrive(true);
+		Com_Printf_State(PRINT_OK, "Ruleset Smackdrive initialized\n");
 	} else if (!strncasecmp(value, "default", sizeof("default"))) {
 		Rulesets_Default();
 		Com_Printf_State(PRINT_OK, "Ruleset default initialized\n");
@@ -723,6 +864,7 @@ static void Rulesets_OnChange_ruleset(cvar_t *var, char *value, qbool *cancel)
 
 	Cmd_ReInitAllMacro();
 	IN_ClearProtectedKeys();
+	Info_SetValueForStarKey(cls.userinfo, "*rsn", value, MAX_INFO_STRING);
 }
 
 int Rulesets_MaxSequentialWaitCommands(void)
@@ -740,6 +882,7 @@ qbool Ruleset_BlockHudPicChange(void)
 	switch (rulesetDef.ruleset) {
 	case rs_qcon:
 	case rs_smackdown:
+	case rs_smackdrive:
 	case rs_thunderdome:
 		return cls.state != ca_disconnected && !(cl.standby || cl.spectator || cls.demoplayback);
 	default:
