@@ -194,6 +194,10 @@ cvar_t sv_pext_mvdsv_serversideweapon = { "sv_pext_mvdsv_serversideweapon", "1"
 
 cvar_t sv_extlimits = { "sv_extlimits", "2" };
 
+#if defined(FTE_PEXT_TRANS)
+cvar_t sv_pext_ezquake_verfortrans = {"pext_ezquake_verfortrans", "7814", CVAR_NONE};
+#endif
+
 qbool sv_error = false;
 
 client_t *WatcherId = NULL; // QW262
@@ -276,29 +280,24 @@ void SV_Shutdown (char *finalmsg)
 SV_Error
 
 Sends a datagram to all the clients informing them of the server crash,
-then exits
+then stops the server
 ================
 */
 void SV_Error (char *error, ...)
 {
-	static qbool inerror = false;
 	static char string[1024];
 	va_list argptr;
 
 	sv_error = true;
 
-	if (inerror)
-		Sys_Error ("SV_Error: recursively entered (%s)", string);
-
-	inerror = true;
-
 	va_start (argptr, error);
 	vsnprintf (string, sizeof (string), error, argptr);
 	va_end (argptr);
 
 	SV_Shutdown (va ("SV_Error: %s\n", string));
 
-	Sys_Error ("SV_Error: %s", string);
+	Host_EndGame();
+	Host_Error("SV_Error: %s", string);
 }
 
 static void SV_FreeHeadDelayedPacket(client_t *cl) {
@@ -418,7 +417,7 @@ void SV_DropClient(client_t* drop)
 // <-- MD
 
 	drop->old_frags = 0;
-	drop->edict->v.frags = 0.0;
+	drop->edict->v->frags = 0.0;
 	drop->name[0] = 0;
 
 	Info_RemoveAll(&drop->_userinfo_ctx_);
@@ -679,6 +678,22 @@ static void SVC_LastScores (void)
 	SV_EndRedirect ();
 }
 
+/*
+===================
+SVC_LastStats
+===================
+*/
+void SV_LastStats_f (void);
+static void SVC_LastStats (void)
+{
+	if(!(int)sv_allowlastscores.value)
+		return;
+
+	SV_BeginRedirect (RD_PACKET);
+	SV_LastStats_f ();
+	SV_EndRedirect ();
+}
+
 /*
 ===================
 SVC_DemoList
@@ -1385,10 +1400,10 @@ static void SVC_DirectConnect (void)
 
 	edictnum = (newcl-svs.clients)+1;
 	ent = EDICT_NUM(edictnum);
-	ent->e->free = false;
+	ent->e.free = false;
 	newcl->edict = ent;
 	// restore client name.
-	PR_SetEntityString(ent, ent->v.netname, newcl->name);
+	PR_SetEntityString(ent, ent->v->netname, newcl->name);
 
 	s = ( vip ? va("%d", vip) : "" );
 
@@ -1893,6 +1908,8 @@ static void SV_ConnectionlessPacket (void)
 		SVC_GetChallenge ();
 	else if (!strcmp(c,"lastscores"))
 		SVC_LastScores ();
+	else if (!strcmp(c,"laststats"))
+		SVC_LastStats ();
 	else if (!strcmp(c,"dlist"))
 		SVC_DemoList ();
 	else if (!strcmp(c,"dlistr"))
@@ -3120,6 +3137,7 @@ int SV_BoundRate (qbool dl, int rate)
 
 	if (rate < 500)
 		rate = 500;
+
 	if (rate > 100000 * MAX_DUPLICATE_PACKETS)
 		rate = 100000 * MAX_DUPLICATE_PACKETS;
 
@@ -3324,9 +3342,9 @@ void SV_InitLocal (void)
 	extern	cvar_t	pm_airstep;
 	extern	cvar_t	pm_pground;
 	extern  cvar_t  pm_rampjump;
-	//extern	cvar_t	pm_slidefix;
+	extern	cvar_t	pm_slidefix;
 	extern	cvar_t	pm_ktjump;
-	//extern	cvar_t	pm_bunnyspeedcap;
+	extern	cvar_t	pm_bunnyspeedcap;
 
 	// qws = QuakeWorld Server information
 	static cvar_t qws_name = { "qws_name", SERVER_NAME, CVAR_ROM };
@@ -3431,9 +3449,9 @@ void SV_InitLocal (void)
 	Cvar_Register (&sv_antilag_no_pred);
 	Cvar_Register (&sv_antilag_projectiles);
 
-	//Cvar_Register (&pm_bunnyspeedcap);
+	Cvar_Register (&pm_bunnyspeedcap);
 	Cvar_Register (&pm_ktjump);
-	//Cvar_Register (&pm_slidefix);
+	Cvar_Register (&pm_slidefix);
 	Cvar_Register (&pm_pground);
 	Cvar_Register (&pm_airstep);
 	Cvar_Register (&pm_rampjump);
@@ -3488,6 +3506,10 @@ void SV_InitLocal (void)
 	Cvar_Register (&sv_pext_mvdsv_serversideweapon);
 #endif
 
+#ifdef FTE_PEXT_TRANS
+	Cvar_Register(&sv_pext_ezquake_verfortrans);
+#endif
+
 	Cvar_Register (&sv_reliable_sound);
 
 	Cvar_Register(&qws_name);
@@ -3551,7 +3573,12 @@ void SV_InitLocal (void)
 #ifdef FTE_PEXT_SPAWNSTATIC2
 	svs.fteprotocolextensions |= FTE_PEXT_SPAWNSTATIC2;
 #endif
-
+#ifdef FTE_PEXT_TRANS
+    svs.fteprotocolextensions |= FTE_PEXT_TRANS;
+#endif
+#ifdef FTE_PEXT_COLOURMOD
+	svs.fteprotocolextensions |= FTE_PEXT_COLOURMOD;
+#endif
 #ifdef FTE_PEXT2_VOICECHAT
 	svs.fteprotocolextensions2 |= FTE_PEXT2_VOICECHAT;
 #endif
@@ -3885,6 +3912,9 @@ void Host_Init (int argc, char **argv, int default_memsize)
 
 	Con_Printf ("%4.1f megabyte heap\n", (float)hunk_size / (1024 * 1024));
 	Con_Printf ("QuakeWorld Initialized\n");
+#ifndef	WWW_INTEGRATION
+	Con_Printf ("www authentication disabled (no curl support)\n");
+#endif
 
 	Cbuf_InsertText ("exec server.cfg\n");
 
