@@ -500,7 +500,7 @@ char *Macro_DateIso(void) {
 	time (&t);
 	if (!(ptm = localtime (&t)))
 		return "#bad date#";
-	strftime (macro_buf, sizeof(macro_buf) - 1, "%Y-%m-%d_%H-%M-%S", ptm);
+	strftime (macro_buf, sizeof(macro_buf) - 1, "%Y-%m-%d_%H-%M", ptm);
 	return macro_buf;
 }
 
@@ -2413,7 +2413,25 @@ item_t	tp_items[] = {
                         {	it_flag,	&tp_name_flag,	"progs/b_g_key.mdl",
                           {0, 0, 20},	18,
                         },
-                        {	it_flag,	&tp_name_flag,	"progs/flag.mdl",
+						{	it_flag,	&tp_name_flag,	"progs/stag.mdl",
+						  {0, 0, 20},	18,
+						},
+						{	it_flag,	&tp_name_flag,	"progs/basrkey.bsp",
+						  {0, 0, 20},	18,
+						},
+						{	it_flag,	&tp_name_flag,	"progs/basbkey.bsp",
+						  {0, 0, 20},	18,
+						},
+						{	it_flag,	&tp_name_flag,	"progs/ff_flag.mdl",
+						  {0, 0, 20},	18,
+						},
+						{	it_flag,	&tp_name_flag,	"progs/harbflag.mdl",
+						  {0, 0, 20},	18,
+						},
+						{	it_flag,	&tp_name_flag,	"progs/princess.mdl",
+						  {0, 0, 20},	18,
+						},
+						{	it_flag,	&tp_name_flag,	"progs/flag.mdl",
                           {0, 0, 14},	25,
                         },
                         {	it_rune1,	&tp_name_rune1,	"progs/end1.mdl",
