@@ -61,7 +61,7 @@ static const byte color380[4] = {  77, 227, 0, 255 };      // teamkills
 static void VX_TrackerAddSegmented4(const char* lhs_text, const byte* lhs_color, const char* center_text, const byte* center_color, const char* rhs_text, const byte* rhs_color, const char* extra_text, const byte* extra_color);
 #define VX_TrackerAddSegmented(lhs_text, lhs_color, center_text, center_color, rhs_text, rhs_color) VX_TrackerAddSegmented4(lhs_text, lhs_color, center_text, center_color, rhs_text, rhs_color, "", NULL)
 static void VX_TrackerAddWeaponImageSplit(const char* lhs_text, const byte* lhs_color, int weapon, const char* rhs_text, const byte* rhs_color);
-static void VX_TrackerAddWeaponTextSplit(const char* lhs_text, int weapon, const byte* weapon_color, const char* rhs_text);
+static void VX_TrackerAddWeaponTextSplit(char* lhs_text, int weapon, const byte* color, char* rhs_text);
 
 //STREAKS
 typedef struct {
@@ -90,36 +90,39 @@ static int max_active_tracks = 0;
 static void VXSCR_DrawTrackerString(float x_pos, float y_pos, float width, int name_width, qbool proportional, float scale, float image_scale, qbool align_right);
 static void OnChange_TrackerNameWidth(cvar_t* var, char* value, qbool* cancel);
 
-cvar_t r_tracker                                  = {"r_tracker", "1"};
-cvar_t amf_tracker_flags                          = {"r_tracker_flags", "0"};
-cvar_t amf_tracker_frags                          = {"r_tracker_frags", "1"};
-cvar_t amf_tracker_streaks                        = {"r_tracker_streaks", "0"};
-cvar_t amf_tracker_time                           = {"r_tracker_time", "4"};
-cvar_t amf_tracker_messages                       = {"r_tracker_messages", "20"};
-static cvar_t amf_tracker_pickups                 = {"r_tracker_pickups", "0"};
-cvar_t amf_tracker_align_right                    = {"r_tracker_align_right", "1"};
-cvar_t amf_tracker_scale                          = {"r_tracker_scale", "1"};
-static cvar_t amf_tracker_inconsole               = {"r_tracker_inconsole", "0"};
-static cvar_t amf_tracker_x                       = {"r_tracker_x", "0"};
-static cvar_t amf_tracker_y                       = {"r_tracker_y", "0"};
-static cvar_t amf_tracker_frame_color             = {"r_tracker_frame_color", "0 0 0 0", CVAR_COLOR};
-static cvar_t amf_tracker_images_scale            = {"r_tracker_images_scale", "1"};
-static cvar_t amf_tracker_color_good              = {"r_tracker_color_good",     "090", CVAR_TRACKERCOLOR }; // good news
-static cvar_t amf_tracker_color_bad               = {"r_tracker_color_bad",      "900", CVAR_TRACKERCOLOR }; // bad news
-static cvar_t amf_tracker_color_tkgood            = {"r_tracker_color_tkgood",   "990", CVAR_TRACKERCOLOR }; // team kill, not on ur team
-static cvar_t amf_tracker_color_tkbad             = {"r_tracker_color_tkbad",    "009", CVAR_TRACKERCOLOR }; // team kill, on ur team
-static cvar_t amf_tracker_color_myfrag            = {"r_tracker_color_myfrag",   "090", CVAR_TRACKERCOLOR }; // use this color for frag which u done
-static cvar_t amf_tracker_color_fragonme          = {"r_tracker_color_fragonme", "900", CVAR_TRACKERCOLOR }; // use this color when u frag someone
-static cvar_t amf_tracker_color_suicide           = {"r_tracker_color_suicide",  "900", CVAR_TRACKERCOLOR }; // use this color when u suicides
-static cvar_t amf_tracker_string_suicides         = {"r_tracker_string_suicides", " (suicides)"};
-static cvar_t amf_tracker_string_died             = {"r_tracker_string_died",     " (died)"};
-static cvar_t amf_tracker_string_teammate         = {"r_tracker_string_teammate", "teammate"};
-static cvar_t amf_tracker_string_enemy            = {"r_tracker_string_enemy",    "enemy"};
-static cvar_t amf_tracker_name_width              = {"r_tracker_name_width",      "0", 0, OnChange_TrackerNameWidth};
-static cvar_t amf_tracker_own_frag_prefix         = {"r_tracker_own_frag_prefix", "You fragged "};
-static cvar_t amf_tracker_positive_enemy_suicide  = {"r_tracker_positive_enemy_suicide", "0"};	// Medar wanted it to be customizable
-static cvar_t amf_tracker_positive_enemy_vs_enemy = {"r_tracker_positive_enemy_vs_enemy", "0"};
-static cvar_t amf_tracker_proportional            = {"r_tracker_proportional", "0"};
+cvar_t r_tracker                                   = {"r_tracker", "1"};
+cvar_t amf_tracker_flags                           = {"r_tracker_flags", "0"};
+cvar_t amf_tracker_frags                           = {"r_tracker_frags", "1"};
+cvar_t amf_tracker_streaks                         = {"r_tracker_streaks", "0"};
+cvar_t amf_tracker_time                            = {"r_tracker_time", "4"};
+cvar_t amf_tracker_messages                        = {"r_tracker_messages", "20"};
+static cvar_t amf_tracker_colorfix				         = {"r_tracker_colorfix", "0"};
+static cvar_t amf_tracker_pickups                  = {"r_tracker_pickups", "0"};
+cvar_t amf_tracker_align_right                     = {"r_tracker_align_right", "1"};
+cvar_t amf_tracker_scale                           = {"r_tracker_scale", "1"};
+static cvar_t amf_tracker_inconsole                = {"r_tracker_inconsole", "0"};
+static cvar_t amf_tracker_inconsole_colored_weapon = {"r_tracker_inconsole_colored_weapon", "0"};
+static cvar_t amf_tracker_x                        = {"r_tracker_x", "0"};
+static cvar_t amf_tracker_y                        = {"r_tracker_y", "0"};
+static cvar_t amf_tracker_frame_color              = {"r_tracker_frame_color", "0 0 0 0", CVAR_COLOR};
+static cvar_t amf_tracker_images_scale             = {"r_tracker_images_scale", "1"};
+static cvar_t amf_tracker_color_good               = {"r_tracker_color_good",     "090", CVAR_TRACKERCOLOR }; // good news
+static cvar_t amf_tracker_color_bad                = {"r_tracker_color_bad",      "900", CVAR_TRACKERCOLOR }; // bad news
+static cvar_t amf_tracker_color_tkgood             = {"r_tracker_color_tkgood",   "990", CVAR_TRACKERCOLOR }; // team kill, not on ur team
+static cvar_t amf_tracker_color_tkbad              = {"r_tracker_color_tkbad",    "009", CVAR_TRACKERCOLOR }; // team kill, on ur team
+static cvar_t amf_tracker_color_myfrag             = {"r_tracker_color_myfrag",   "090", CVAR_TRACKERCOLOR }; // use this color for frag which u done
+static cvar_t amf_tracker_color_fragonme           = {"r_tracker_color_fragonme", "900", CVAR_TRACKERCOLOR }; // use this color when u frag someone
+static cvar_t amf_tracker_color_suicide            = {"r_tracker_color_suicide",  "900", CVAR_TRACKERCOLOR }; // use this color when u suicides
+static cvar_t amf_tracker_string_suicides          = {"r_tracker_string_suicides", " (suicides)"};
+static cvar_t amf_tracker_string_died              = {"r_tracker_string_died",     " (died)"};
+static cvar_t amf_tracker_string_teammate          = {"r_tracker_string_teammate", "teammate"};
+static cvar_t amf_tracker_string_enemy             = {"r_tracker_string_enemy",    "enemy"};
+static cvar_t amf_tracker_string_inconsole_prefix  = {"r_tracker_string_inconsole_prefix", ""};
+static cvar_t amf_tracker_name_width               = {"r_tracker_name_width",      "0", 0, OnChange_TrackerNameWidth};
+static cvar_t amf_tracker_own_frag_prefix          = {"r_tracker_own_frag_prefix", "You fragged "};
+static cvar_t amf_tracker_positive_enemy_suicide   = {"r_tracker_positive_enemy_suicide", "0"};	// Medar wanted it to be customizable
+static cvar_t amf_tracker_positive_enemy_vs_enemy  = {"r_tracker_positive_enemy_vs_enemy", "0"};
+static cvar_t amf_tracker_proportional             = {"r_tracker_proportional", "0"};
 
 #define MAX_TRACKERMESSAGES 30
 #define MAX_TRACKER_MSG_LEN 500
@@ -187,7 +190,9 @@ void InitTracker(void)
 	Cvar_Register(&amf_tracker_flags);
 	Cvar_Register(&amf_tracker_streaks);
 	Cvar_Register(&amf_tracker_messages);
+	Cvar_Register(&amf_tracker_colorfix);
 	Cvar_Register(&amf_tracker_inconsole);
+	Cvar_Register(&amf_tracker_inconsole_colored_weapon);
 	Cvar_Register(&amf_tracker_time);
 	Cvar_Register(&amf_tracker_align_right);
 	Cvar_Register(&amf_tracker_x);
@@ -209,6 +214,7 @@ void InitTracker(void)
 	Cvar_Register(&amf_tracker_string_died);
 	Cvar_Register(&amf_tracker_string_teammate);
 	Cvar_Register(&amf_tracker_string_enemy);
+	Cvar_Register(&amf_tracker_string_inconsole_prefix);
 
 	Cvar_Register(&amf_tracker_name_width);
 	Cvar_Register(&amf_tracker_own_frag_prefix);
@@ -313,16 +319,16 @@ static qbool VX_TrackerStringPrintSegments(const char* text1, const char* text2,
 
 	switch (amf_tracker_inconsole.integer) {
 		case 1:
-			Com_Printf("%s%s%s%s%s%s%s\n", text1 ? text1 : "", text1 && text2 ? " " : "", text2 ? text2 : "", text2 && text3 ? " " : "", text3 ? text3 : "", text3 && text4 ? " " : "", text4 ? text4 : "");
+			Com_Printf("%s%s%s%s%s%s%s%s\n", amf_tracker_string_inconsole_prefix.string, text1 ? text1 : "", text1 && text2 ? " " : "", text2 ? text2 : "", text2 && text3 ? " " : "", text3 ? text3 : "", text3 && text4 ? " " : "", text4 ? text4 : "");
 			return false;
 		case 2:
-			Com_Printf("%s%s%s%s%s%s%s\n", text1 ? text1 : "", text1 && text2 ? " " : "", text2 ? text2 : "", text2 && text3 ? " " : "", text3 ? text3 : "", text3 && text4 ? " " : "", text4 ? text4 : "");
+			Com_Printf("%s%s%s%s%s%s%s%s\n", amf_tracker_string_inconsole_prefix.string, text1 ? text1 : "", text1 && text2 ? " " : "", text2 ? text2 : "", text2 && text3 ? " " : "", text3 ? text3 : "", text3 && text4 ? " " : "", text4 ? text4 : "");
 			return true;
 		case 3:
 		{
 			int flags = Print_flags[Print_current];
 			Print_flags[Print_current] |= PR_NONOTIFY;
-			Com_Printf("%s%s%s%s%s%s%s\n", text1 ? text1 : "", text1 && text2 ? " " : "", text2 ? text2 : "", text2 && text3 ? " " : "", text3 ? text3 : "", text3 && text4 ? " " : "", text4 ? text4 : "");
+			Com_Printf("%s%s%s%s%s%s%s%s\n", amf_tracker_string_inconsole_prefix.string, text1 ? text1 : "", text1 && text2 ? " " : "", text2 ? text2 : "", text2 && text3 ? " " : "", text3 ? text3 : "", text3 && text4 ? " " : "", text4 ? text4 : "");
 			Print_flags[Print_current] = flags;
 			return true;
 		}
@@ -356,6 +362,8 @@ static qbool VX_TrackerStringPrintSegmentsWithImage(const char* text1, const byt
 
 	Print_flags[Print_current] |= (PR_NORESET | (suppress_from_notify ? PR_NONOTIFY : 0));
 
+	Com_Printf("%s", amf_tracker_string_inconsole_prefix.string);
+
 	if (text1 && text1[0]) {
 		if (text1_color) {
 			Com_Printf("&c%x%x%x%s&r ", text1_color[0] / 16, text1_color[1] / 16, text1_color[2] / 16, text1);
@@ -524,32 +532,43 @@ static void VX_TrackerAddWeaponImageSplit(const char* lhs_text, const byte* lhs_
 	}
 }
 
-static void VX_TrackerAddWeaponTextSplit(const char* lhs_text, int weapon, const byte* weapon_color, const char* rhs_text)
+static void VX_TrackerAddWeaponTextSplit(char* lhs_text, int weapon, const byte* color, char* rhs_text)
 {
 	trackmsg_t* msg;
 	int i;
+	char *weapon_text;
 
 	if (((!lhs_text || !lhs_text[0]) && (!rhs_text || !rhs_text[0])) || CL_Demo_SkipMessage(true)) {
 		return;
 	}
 
-	if (!VX_TrackerStringPrintSegments(lhs_text, GetWeaponName(weapon), rhs_text, NULL)) {
+	weapon_text = amf_tracker_inconsole_colored_weapon.integer == 0
+		? GetWeaponName(weapon)
+		: GetColoredWeaponName(weapon, color);
+
+	if (!VX_TrackerStringPrintSegments(lhs_text, weapon_text, rhs_text, NULL)) {
 		return;
 	}
 
 	msg = VX_NewTrackerMsg();
 	if (msg) {
 		msg->pad = lhs_text && rhs_text && lhs_text[0] && rhs_text[0];
-		VX_TrackerAddTextSegment(msg, lhs_text, color_white);
+		VX_TrackerAddTextSegment(
+			msg,
+			amf_tracker_colorfix.integer ? Q_normalizetext(lhs_text) : lhs_text,
+			amf_tracker_colorfix.integer ? color : color_white);
 		for (i = 0; i < weapon_labels[weapon].count; ++i) {
 			if (weapon_labels[weapon].colors[i][3]) {
 				VX_TrackerAddFlaggedTextSegment(msg, weapon_labels[weapon].label + weapon_labels[weapon].starts[i], weapon_labels[weapon].colors[i], TEXTFLAG_WEAPON);
 			}
 			else {
-				VX_TrackerAddFlaggedTextSegment(msg, weapon_labels[weapon].label + weapon_labels[weapon].starts[i], weapon_color, TEXTFLAG_WEAPON);
+				VX_TrackerAddFlaggedTextSegment(msg, weapon_labels[weapon].label + weapon_labels[weapon].starts[i], color, TEXTFLAG_WEAPON);
 			}
 		}
-		VX_TrackerAddTextSegment(msg, rhs_text, color_white);
+		VX_TrackerAddTextSegment(
+			msg,
+			amf_tracker_colorfix.integer ? Q_normalizetext(rhs_text) : rhs_text,
+			amf_tracker_colorfix.integer ? color : color_white);
 		VX_PreProcessMessage(msg);
 	}
 }
@@ -755,6 +774,7 @@ void VX_TrackerSuicide(int player, int weapon, int count)
 
 void VX_TrackerFragXvsY(int player, int killer, int weapon, int player_wcount, int killer_wcount)
 {
+	int colorfix = amf_tracker_colorfix.integer;
 	char outstring[20];
 	char player_name[MAX_SCOREBOARDNAME];
 	char killer_name[MAX_SCOREBOARDNAME];
@@ -772,7 +792,7 @@ void VX_TrackerFragXvsY(int player, int killer, int weapon, int player_wcount, i
 			Q_normalizetext(player_name);
 			Q_normalizetext(killer_name);
 
-			VX_TrackerAddWeaponImageSplit(killer_name, XvsYFullColor(player, killer), weapon, player_name, XvsYFullColor(killer, player));
+			VX_TrackerAddWeaponImageSplit(killer_name, XvsYFullColor(player, killer), weapon, player_name, colorfix ? XvsYFullColor(player, killer) : XvsYFullColor(killer, player));
 		}
 		else {
 			VX_TrackerAddWeaponTextSplit(killer_name, weapon, XvsYFullColor(player, killer), player_name);
